@@ -2,30 +2,31 @@ package cli
 
 import (
 	"fmt"
+	"strings"
 
+	"github.com/jandedobbeleer/oh-my-posh/src/cache"
+	"github.com/jandedobbeleer/oh-my-posh/src/config"
 	"github.com/jandedobbeleer/oh-my-posh/src/runtime"
-	"github.com/jandedobbeleer/oh-my-posh/src/upgrade"
 
 	"github.com/spf13/cobra"
 )
 
 var (
-	toggleUse  = "%s [notice]"
-	toggleLong = `%s a feature
-
-This command is used to %s one of the following features:
-
-- notice`
+	toggleHelpText = `%s one of the following features:
+`
 	toggleArgs = []string{
-		"notice",
+		config.UPGRADENOTICE,
+		config.AUTOUPGRADE,
 	}
+	toggleUse  = fmt.Sprintf("%%s [%s]", strings.Join(toggleArgs, "|"))
+	toggleLong = strings.Join(append([]string{toggleHelpText}, toggleArgs...), "\n- ")
 )
 
 // getCmd represents the get command
 var enableCmd = &cobra.Command{
 	Use:       fmt.Sprintf(toggleUse, "enable"),
 	Short:     "Enable a feature",
-	Long:      fmt.Sprintf(toggleLong, "Enable", "enable"),
+	Long:      fmt.Sprintf(toggleLong, "Enable"),
 	ValidArgs: toggleArgs,
 	Args:      NoArgsOrOneValidArg,
 	Run: func(cmd *cobra.Command, args []string) {
@@ -42,25 +43,24 @@ func init() {
 }
 
 func toggleFeature(cmd *cobra.Command, feature string, enable bool) {
-	env := &runtime.Terminal{
-		CmdFlags: &runtime.Flags{
-			Shell:     shellName,
-			SaveCache: true,
-		},
+	flags := &runtime.Flags{
+		Shell:     shellName,
+		SaveCache: true,
 	}
 
-	env.Init()
+	env := &runtime.Terminal{}
+	env.Init(flags)
 	defer env.Close()
 
-	switch feature {
-	case "notice":
-		if enable {
-			env.Cache().Delete(upgrade.CACHEKEY)
-			return
-		}
-
-		env.Cache().Set(upgrade.CACHEKEY, "disabled", -1)
-	default:
+	if len(feature) == 0 {
 		_ = cmd.Help()
+		return
 	}
+
+	if enable {
+		env.Cache().Set(feature, "true", cache.INFINITE)
+		return
+	}
+
+	env.Cache().Delete(feature)
 }
