@@ -2,8 +2,11 @@ package segments
 
 import (
 	"fmt"
+	"path/filepath"
+	"sort"
 	"strings"
 
+	"github.com/jandedobbeleer/oh-my-posh/src/log"
 	"github.com/jandedobbeleer/oh-my-posh/src/properties"
 	"github.com/jandedobbeleer/oh-my-posh/src/runtime"
 	"github.com/jandedobbeleer/oh-my-posh/src/template"
@@ -98,20 +101,58 @@ const (
 	BranchTemplate properties.Property = "branch_template"
 )
 
+func (s *scm) RelativeDir() string {
+	if len(s.Dir) == 0 {
+		return ""
+	}
+
+	pwd := s.env.Pwd()
+	log.Debug("scm.Dir:", s.Dir, "pwd:", pwd)
+
+	rel, err := filepath.Rel(s.Dir, pwd)
+	if err != nil {
+		log.Error(err)
+	}
+
+	if rel == "." || len(rel) == 0 {
+		log.Debug("scm.Dir is the same as the current working directory, returning empty string")
+		return ""
+	}
+
+	return rel
+}
+
 func (s *scm) formatBranch(branch string) string {
 	mappedBranches := s.props.GetKeyValueMap(MappedBranches, make(map[string]string))
-	for key, value := range mappedBranches {
-		matchSubFolders := strings.HasSuffix(key, "*")
 
-		if matchSubFolders && len(key) > 1 {
-			key = key[0 : len(key)-1] // remove trailing /* or \*
+	// sort the keys alphabetically
+	keys := make([]string, 0, len(mappedBranches))
+	for k := range mappedBranches {
+		keys = append(keys, k)
+	}
+	sort.Strings(keys)
+
+	const wildcard = "*"
+
+	for _, key := range keys {
+		if key == wildcard {
+			branch = mappedBranches[key]
+			break
 		}
 
-		if !strings.HasPrefix(branch, key) {
+		matchSubFolders := strings.HasSuffix(key, wildcard)
+		subfolderKey := strings.TrimSuffix(key, wildcard)
+
+		if matchSubFolders && strings.HasPrefix(branch, subfolderKey) {
+			branch = strings.Replace(branch, subfolderKey, mappedBranches[key], 1)
+			break
+		}
+
+		if matchSubFolders || branch != key {
 			continue
 		}
 
-		branch = strings.Replace(branch, key, value, 1)
+		branch = strings.Replace(branch, key, mappedBranches[key], 1)
 		break
 	}
 
@@ -133,7 +174,7 @@ func (s *scm) formatBranch(branch string) string {
 	return text
 }
 
-func (s *scm) FileContents(folder, file string) string {
+func (s *scm) fileContent(folder, file string) string {
 	return strings.Trim(s.env.FileContent(folder+"/"+file), " \r\n")
 }
 
